/**
 * Represents a Catalog Item.
 */
export class CatalogItem {
    /**
     * Method to get a known catalog item
     *
     * Usage:
     *
     * ```
     * var req = CatalogItem.get(ItemType.Part, '3001');
     * client.send(req).then(item => console.log(item));
     * ```
     *
     * @param {string} itemType Catalog item type i.e. - MINIFIG, PART, SET, BOOK, GEAR, CATALOG, INSTRUCTION, UNSORTED_LOT, ORIGINAL_BOX
     * @param {string} itemNumber Catalog item number
     * @return {BricklinkRequest} A request that is ready to execute with a client.
     */
    static get(itemType: string, itemNumber: string): BricklinkRequest;
    /**
     * Create a new instance of a Catalog Item
     * @param {object} [data] Data typically returned from an API response.
     */
    constructor(data?: object);
    /** @type {string} */
    no: string;
    /** @type {string} */
    name: string;
    /** @type {string} */
    type: string;
    /** @type {number} */
    category_id: number;
    /** @type {string} */
    alternate_no: string;
    /** @type {string} */
    image_url: string;
    /** @type {string} */
    thumbnail_url: string;
    /** @type {number} */
    weight: number;
    /** @type {string} */
    dim_x: string;
    /** @type {string} */
    dim_y: string;
    /** @type {string} */
    dim_z: string;
    /** @type {string} */
    year_released: string;
    /** @type {string} */
    description: string;
    /** @type {boolean} */
    is_obsolete: boolean;
    /** @type {string} */
    language_code: string;
}
import { BricklinkRequest } from '../request';
