/**
 * Represents an image for a specific color of a catalog item.
 */
export class ItemImage {
    /**
     * Method to get an image of a catalog item.
     *
     * Usage:
     *
     * ```
     * var req = ItemImage.get(ItemType.Part, '3001', 0);
     * client.send(req).then(image => console.log(image));
     * ```
     *
     * @param {string} itemType Catalog item type
     * @param {string} itemNumber Catalog item number
     * @param {number} colorId Catalog item's color id.
     */
    static get(itemType: string, itemNumber: string, colorId: number): BricklinkRequest;
    /**
     * Create an instance of Item Image
     * @param {object} data The API response data
     * @param {number} [data.color_id=0] Color Id of the image.
     * @param {string} [data.thumbnail_url=''] The Url of the thumbnail image.
     * @param {string} [data.type=''] The type of catalog item as correspondeing to {@link ItemType}.
     * @param {string} [data.no=''] The catalog item's identification number.
     */
    constructor(data: {
        color_id?: number;
        thumbnail_url?: string;
        type?: string;
        no?: string;
    });
    /** @type {number} */
    color_id: number;
    /** @type {string} */
    thumbnail_url: string;
    /** @type {string} */
    type: string;
    /** @type {string} */
    no: string;
}
import { BricklinkRequest } from '../request';
