/**
 * Represents a known color object.
 */
export class KnownColor {
    /**
     * Method to get a list of known color_id for a given catalog item.
     *
     * Usage:
     *
     * ```
     * var req = KnownColor.get(ItemType.Part, '3001');
     * client.send(req).then(colors => console.log(colors));
     * ```
     *
     * @param {string} itemType Catalog item type
     * @param {string} itemNumber Catalog item number
     * @return {BricklinkRequest} A request that resolves to a list of {@link KnownColor}.
     */
    static get(itemType: string, itemNumber: string): BricklinkRequest;
    /**
     * Create a new instance of a known color
     * @param {object} [data] API response data.
     * @param {number} [data.color_id=0] The color id.
     * @param {number} [data.quantity=0] The quantity of items with this known color.
     */
    constructor(data?: {
        color_id?: number;
        quantity?: number;
    });
    /** @type {number} */
    color_id: number;
    /** @type {number} */
    quantity: number;
}
import { BricklinkRequest } from '../request';
