"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SupersetOptions = exports.SupersetEntry = exports.Superset = void 0;
var _request = require("../request");
var _catalogItem = require("./catalogItem");
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
/**
 * Represents entries of a superset item.
 */
var SupersetEntry = /*#__PURE__*/_createClass(
/**
 * Create an instance of a subset entry
 * @param {object} [data] The API response data
 * @param {object} [data.item] Item information
 * @param {number} [data.quantity] The number of items in the subset entry.
 * @param {string} [data.appear_as] How the entry appears in the superset item.
 */
function SupersetEntry(data) {
  _classCallCheck(this, SupersetEntry);
  data = data || {};
  /** @type {CatalogItem} */
  this.item = data.item ? new _catalogItem.CatalogItem(data.item) : new _catalogItem.CatalogItem();
  /** @type {number} */
  this.quantity = data.quantity || 0;
  /** @type {string} */
  this.appear_as = data.appear_as || '';
});
/**
 * Represents a super set entry.
 */
exports.SupersetEntry = SupersetEntry;
var Superset = /*#__PURE__*/function () {
  /**
   * Create an instance of a super set item.
   * @param {object} [data] The API response data
   * @param {object[]} [data.entries] Entries for a superset item.
   * @param {number} [data.color_id] The color id of the superset item.
   */
  function Superset(data) {
    _classCallCheck(this, Superset);
    data = data || {};
    /** @type {number} */
    this.color_id = data.color_id || 0;
    var entries = data.entries || [];
    /** @type {SupersetEntry[]} */
    this.entries = entries.map(function (e) {
      return new SupersetEntry(e);
    });
  }

  /**
   * Method to get a superset of a catalog item
   *
   * Usage:
   *
   * ```
   * var req = Superset.get(ItemType.Part, '4593');
   * client.send(req).then(superset => console.log(superset));
   * ```
   *
   * @param {string} itemType Catalog item type
   * @param {string} itemNumber Catalog item number
   * @param {object} options Options that conform to {@link SupersetOptions}.
   * @return {BricklinkRequest} A request that will return an array of {@link Superset} items.
   */
  _createClass(Superset, null, [{
    key: "get",
    value: function get(itemType, itemNumber, options) {
      options = options ? new SupersetOptions(options) : new SupersetOptions();
      var method = _request.BricklinkRequest.GET;
      var uri = "/items/".concat(itemType, "/").concat(itemNumber, "/supersets");
      return new _request.BricklinkRequest(method, uri, options, function (data) {
        return data.map(function (set) {
          return new Superset(set);
        });
      });
    }
  }]);
  return Superset;
}();
/**
 * Options that can be used when make a request for a subset.
 */
exports.Superset = Superset;
var SupersetOptions = /*#__PURE__*/function (_RequestParams) {
  _inherits(SupersetOptions, _RequestParams);
  var _super = _createSuper(SupersetOptions);
  /**
   * Make an instance of SubsetOptions.
   * @param {object} [data] Raw options object.
   * @param {number} [data.color_id] The color of the item.
   */
  function SupersetOptions(data) {
    var _this;
    _classCallCheck(this, SupersetOptions);
    _this = _super.call(this);
    data = data || {};
    /** @type {number|null} */
    _this.color_id = data.color_id || null;
    return _this;
  }
  return _createClass(SupersetOptions);
}(_request.RequestParams);
exports.SupersetOptions = SupersetOptions;