"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Category = void 0;
var _request = require("../request");
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
/**
 * Represents a Category
 */
var Category = /*#__PURE__*/function () {
  /**
   * Create a new instance of a category
   * @param {object} [data] API response data.
   * @param {number} [data.category_id=0] The category id. i.e. - 10
   * @param {string} [data.category_name] The category name. i.e. - Container
   * @param {number} [data.parent_id] The parent category id or 0 if root category. i.e. - 0
   */
  function Category(data) {
    _classCallCheck(this, Category);
    data = data || {};
    /** @type {number} */
    this.category_id = data.category_id || 0;
    /** @type {string} */
    this.category_name = data.category_name || '';
    /** @type {number} */
    this.parent_id = data.parent_id || 0;
  }

  /**
   * Method to get a specific category
   *
   * Usage:
   *
   * ```
   * var req = Category.get(123);
   * client.send(req).then(category => console.log(category));
   * ```
   *
   * @param {number} categoryId Catalog item type
   * @return {BricklinkRequest} A request that resolves to a {@link Category} instance.
   */
  _createClass(Category, null, [{
    key: "get",
    value: function get(categoryId) {
      var method = _request.BricklinkRequest.GET;
      var uri = "/categories/".concat(categoryId);
      return new _request.BricklinkRequest(method, uri, null, function (data) {
        return new Category(data);
      });
    }

    /**
     * Get a list of all colors
     * Usage:
     *
     * ```
     * var req = Category.all();
     * client.send(req).then(categories => console.log(categories));
     * ```
     *
     * @return {BricklinkRequest} A request that resolves to an array of {@link Category}.
     */
  }, {
    key: "all",
    value: function all() {
      var method = _request.BricklinkRequest.GET;
      var uri = "/categories";
      return new _request.BricklinkRequest(method, uri, null, function (data) {
        return data.map(function (d) {
          return new Category(d);
        });
      });
    }
  }]);
  return Category;
}();
exports.Category = Category;